package com.vendor.burn.commands;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.jna.I2cDllByJNA;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.ChipID;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.serial.workers.AbstractBurnerWorker;
import com.vendor.burn.utilitily.I2cUtils;
import com.vendor.burn.utilitily.PropertiesUtility;
import com.vendor.burn.utilitily.ToolUtils;
import java.io.IOException;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.widgets.Display;

public class I2cCommand {
  private static int baudRate;
  
  private static int deviceAddress;
  
  private static boolean connected = false;
  
  private static final int DEFAULT_CHANNEL_ID = 0;
  
  private static final int I2C_BUFFER_LEN = 7;
  
  private static final int MW_DB_CMD_TYPE_DB = 3;
  
  public static final int I2C_RUN_CMD_LEN = 127;
  
  public static final int I2C_RUN_BUFFER_LEN = 124;
  
  public static final int I2C_RUN_MAX_INDEX = 256;
  
  public static final int UPGRADE_FAIL = -1;
  
  public static final int UPGRADE_RUN = 0;
  
  public static final int UPGRADE_FINISH = 1;
  
  public static final int BOOTROM_ADDRESS = 52;
  
  private static final int BOOTROM_DELAY = 15;
  
  private static final int BOOTROM_DELAY1 = 3;
  
  private static final int I2C_SLOW = 0;
  
  private static final int I2C_QUICK = 1;
  
  public static final int GET_CUR_RECEIVED_LEN = 1024;
  
  public static final int WAIT_BOOT_RUN_RECE_LEN = 256;
  
  public static boolean I2cOpenChannel() {
    System.setProperty("jna.encoding", "GBK");
    String baudRateStr = FastbootPreferences.getBaudRate();
    baudRate = I2cUtils.getbaudRateValue(baudRateStr);
    deviceAddress = FastbootPreferences.getDeviceAddress();
    int mode = 0;
    String chipName = ToolUtils.getChipName();
    if (chipName == null) {
      mode = 0;
    } else {
      mode = 1;
    } 
    try {
      int openResult = I2cDllByJNA.instance.I2C_OpenChannel(0, baudRate, mode);
      if (I2cUtils.checkI2cReturn(openResult)) {
        connected = true;
        return true;
      } 
      return false;
    } catch (Exception e) {
      connected = false;
      return false;
    } catch (Error e) {
      connected = false;
      return false;
    } 
  }
  
  public static boolean I2cOpenChannelForBootrom(int address, IFastbootProgressMonitor fastbootMonitor) {
    String baudRateStr;
    System.setProperty("jna.encoding", "GBK");
    if (ToolUtils.isCmdLine()) {
      baudRateStr = PropertiesUtility.queryForString("baudRate");
      if (baudRateStr == null || baudRateStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "baudRate"));
        return false;
      } 
    } else {
      baudRateStr = FastbootPreferences.getBaudRate();
    } 
    baudRate = I2cUtils.getbaudRateValue(baudRateStr);
    deviceAddress = address;
    int mode = 0;
    String chipName = ToolUtils.getChipName();
    if (chipName == null) {
      mode = 0;
    } else {
      mode = 1;
    } 
    try {
      int openResult = I2cDllByJNA.instance.I2C_OpenChannel(0, baudRate, mode);
      if (I2cUtils.checkI2cReturn(openResult, fastbootMonitor)) {
        connected = true;
        return true;
      } 
      return false;
    } catch (Exception e) {
      connected = false;
      return false;
    } catch (Error e) {
      connected = false;
      return false;
    } 
  }
  
  public static boolean sendI2cCmd(int sizetowrite, byte[] inputbuffer, int sizetoread, byte[] outputbuffer) throws IOException {
    int setCmdResult = -1;
    int sendCount = 1;
    int i2cDelay = FastbootPreferences.getI2cDelay();
    int i2cRetryCount = FastbootPreferences.getI2cRetryCount();
    try {
      while (setCmdResult != 0) {
        try {
          Thread.sleep(i2cDelay);
        } catch (InterruptedException interruptedException) {}
        setCmdResult = I2cDllByJNA.instance.I2C_DeviceStream(0, deviceAddress, sizetowrite, inputbuffer, sizetoread, outputbuffer);
        System.out.println("setCmdResult: " + setCmdResult + "sendCount: " + sendCount);
        sendCount++;
        if (sendCount > i2cRetryCount)
          break; 
      } 
    } catch (Exception e) {
      Display.getDefault().syncExec((Runnable)new Object());
      return false;
    } catch (Error e) {
      connected = false;
      Display.getDefault().syncExec((Runnable)new Object());
      return false;
    } 
    return I2cUtils.checkI2cReturn(setCmdResult);
  }
  
  public static boolean sendI2cCmdForBootrom(int sizetowrite, byte[] inputbuffer, int sizetoread, byte[] outputbuffer, int i2cRetryCount, AbstractBurnerWorker worker) throws IOException {
    // Byte code:
    //   0: iconst_m1
    //   1: istore #6
    //   3: iconst_0
    //   4: istore #7
    //   6: aconst_null
    //   7: astore #8
    //   9: invokestatic isDebugOn : ()Z
    //   12: ifeq -> 55
    //   15: new com/vendor/burn/analysis/TimeLogger
    //   18: dup
    //   19: invokespecial <init> : ()V
    //   22: astore #8
    //   24: aload_1
    //   25: ifnull -> 41
    //   28: aload #8
    //   30: ldc 'Send I2C input data'
    //   32: aload_1
    //   33: arraylength
    //   34: i2l
    //   35: invokevirtual logStart : (Ljava/lang/String;J)V
    //   38: goto -> 55
    //   41: aload_3
    //   42: ifnull -> 55
    //   45: aload #8
    //   47: ldc 'Receive I2C output data'
    //   49: aload_3
    //   50: arraylength
    //   51: i2l
    //   52: invokevirtual logStart : (Ljava/lang/String;J)V
    //   55: bipush #15
    //   57: istore #9
    //   59: invokestatic isChipBranchSeries6Series : ()Z
    //   62: ifeq -> 68
    //   65: iconst_3
    //   66: istore #9
    //   68: iload #6
    //   70: ifeq -> 115
    //   73: iload #9
    //   75: i2l
    //   76: invokestatic sleep : (J)V
    //   79: goto -> 84
    //   82: astore #10
    //   84: getstatic com/vendor/burn/jna/I2cDllByJNA.instance : Lcom/vendor/burn/jna/I2cDllByJNA;
    //   87: iconst_0
    //   88: getstatic com/vendor/burn/commands/I2cCommand.deviceAddress : I
    //   91: iload_0
    //   92: aload_1
    //   93: iload_2
    //   94: aload_3
    //   95: invokeinterface I2C_DeviceStream : (III[BI[B)I
    //   100: istore #6
    //   102: iinc #7, 1
    //   105: iload #7
    //   107: iload #4
    //   109: if_icmple -> 68
    //   112: goto -> 115
    //   115: goto -> 126
    //   118: astore #10
    //   120: iconst_0
    //   121: ireturn
    //   122: astore #10
    //   124: iconst_0
    //   125: ireturn
    //   126: invokestatic isDebugOn : ()Z
    //   129: ifeq -> 166
    //   132: aload #8
    //   134: ifnull -> 166
    //   137: aload #8
    //   139: invokevirtual logEnd : ()V
    //   142: aload #5
    //   144: iload #7
    //   146: <illegal opcode> makeConcatWithConstants : (I)Ljava/lang/String;
    //   151: invokevirtual debugPrintln : (Ljava/lang/String;)V
    //   154: aload #5
    //   156: aload #8
    //   158: ldc 'Single I2C time statistics'
    //   160: invokevirtual exportLog : (Ljava/lang/String;)Ljava/lang/String;
    //   163: invokevirtual debugPrintln : (Ljava/lang/String;)V
    //   166: iload #6
    //   168: getstatic com/vendor/burn/model/FT_STATUS.FT_OK : Lcom/vendor/burn/model/FT_STATUS;
    //   171: invokevirtual ordinal : ()I
    //   174: if_icmpne -> 179
    //   177: iconst_1
    //   178: ireturn
    //   179: iconst_0
    //   180: ireturn
    // Line number table:
    //   Java source line number -> byte code offset
    //   #242	-> 0
    //   #243	-> 3
    //   #245	-> 6
    //   #246	-> 9
    //   #247	-> 15
    //   #248	-> 24
    //   #249	-> 28
    //   #251	-> 41
    //   #252	-> 45
    //   #257	-> 55
    //   #258	-> 59
    //   #259	-> 65
    //   #262	-> 68
    //   #265	-> 73
    //   #268	-> 79
    //   #266	-> 82
    //   #270	-> 84
    //   #271	-> 95
    //   #274	-> 102
    //   #275	-> 105
    //   #276	-> 112
    //   #283	-> 115
    //   #279	-> 118
    //   #280	-> 120
    //   #281	-> 122
    //   #282	-> 124
    //   #285	-> 126
    //   #286	-> 132
    //   #287	-> 137
    //   #288	-> 142
    //   #289	-> 154
    //   #292	-> 166
    //   #293	-> 177
    //   #295	-> 179
    // Local variable table:
    //   start	length	slot	name	descriptor
    //   120	2	10	e	Ljava/lang/Exception;
    //   124	2	10	e	Ljava/lang/Error;
    //   0	181	0	sizetowrite	I
    //   0	181	1	inputbuffer	[B
    //   0	181	2	sizetoread	I
    //   0	181	3	outputbuffer	[B
    //   0	181	4	i2cRetryCount	I
    //   0	181	5	worker	Lcom/vendor/burn/serial/workers/AbstractBurnerWorker;
    //   3	178	6	setCmdResult	I
    //   6	175	7	sendCount	I
    //   9	172	8	sendI2cTime	Lcom/vendor/burn/analysis/TimeLogger;
    //   59	122	9	sleepTime	I
    // Exception table:
    //   from	to	target	type
    //   68	115	118	java/lang/Exception
    //   68	115	122	java/lang/Error
    //   73	79	82	java/lang/InterruptedException
  }
  
  public static void I2cCloseChannel() {
    if (connected)
      try {
        I2cDllByJNA.instance.I2C_CloseChannel(0);
        connected = false;
      } catch (Exception e) {
        Display.getDefault().syncExec((Runnable)new Object());
      } catch (Error e) {
        connected = false;
        Display.getDefault().syncExec((Runnable)new Object());
      }  
  }
  
  public static boolean sendUpgradeStart(int fileLen, boolean isCompress) {
    byte[] buffer = new byte[7];
    buffer[1] = (byte)I2cCmd.MW_DB_SET_UPGRADE_START.ordinal();
    buffer[2] = (byte)(fileLen & 0xFF);
    buffer[3] = (byte)(fileLen >> 8 & 0xFF);
    buffer[4] = (byte)(fileLen >> 16 & 0xFF);
    buffer[5] = (byte)(fileLen >> 24 & 0xFF);
    buffer[6] = (byte)booleanToInt(isCompress);
    int checksum = checksum(buffer);
    int temp1 = 3;
    int temp2 = checksum << 4 & 0xF0;
    buffer[0] = (byte)(temp1 | temp2);
    try {
      return sendI2cCmd(buffer.length, buffer, 0, null);
    } catch (IOException e) {
      return false;
    } 
  }
  
  public static boolean sendUpgradeRun(int index, byte[] runData) {
    byte[] buffer = new byte[127];
    buffer[1] = (byte)I2cCmd.MW_DB_SET_UPGRADE_RUN.ordinal();
    buffer[2] = (byte)index;
    for (int i = 3; i < 127; i++)
      buffer[i] = runData[i - 3]; 
    int checksum = checksumForRun(buffer);
    int temp1 = 3;
    int temp2 = checksum << 4 & 0xF0;
    buffer[0] = (byte)(temp1 | temp2);
    try {
      return sendI2cCmd(buffer.length, buffer, 0, null);
    } catch (IOException e) {
      return false;
    } 
  }
  
  public static boolean sendUpgradeFinish(int address, ChipID chipID) {
    byte[] buffer = new byte[7];
    buffer[1] = (byte)I2cCmd.MW_DB_SET_UPGRADE_FINISH.ordinal();
    buffer[2] = (byte)(address & 0xFF);
    buffer[3] = (byte)(address >> 8 & 0xFF);
    buffer[4] = (byte)(address >> 16 & 0xFF);
    buffer[5] = (byte)(address >> 24 & 0xFF);
    buffer[6] = (byte)chipID.ordinal();
    int checksum = checksum(buffer);
    int temp1 = 3;
    int temp2 = checksum << 4 & 0xF0;
    buffer[0] = (byte)(temp1 | temp2);
    try {
      return sendI2cCmd(buffer.length, buffer, 0, null);
    } catch (IOException e) {
      return false;
    } 
  }
  
  public static String bytesToHexString(byte[] src) {
    if (src == null || src.length <= 0)
      return null; 
    StringBuffer sb = new StringBuffer();
    for (byte b : src) {
      sb.append(String.format("%x ", new Object[] { Byte.valueOf(b) }));
    } 
    return sb.toString();
  }
  
  public static int sendGetUpgradeStatus(int i2cDelay, IFastbootProgressMonitor monitor) {
    byte[] buffer = new byte[7];
    buffer[1] = (byte)I2cCmd.MW_DB_SET_UPGRADE_STATUS.ordinal();
    buffer[2] = 0;
    buffer[3] = 0;
    buffer[4] = 0;
    buffer[5] = 0;
    buffer[6] = 0;
    int checksum = checksum(buffer);
    int temp1 = 3;
    int temp2 = checksum << 4 & 0xF0;
    buffer[0] = (byte)(temp1 | temp2);
    I2cDllByJNA.instance.I2C_DeviceStream(0, deviceAddress, buffer.length, buffer, 0, null);
    try {
      Thread.sleep(i2cDelay);
    } catch (InterruptedException interruptedException) {}
    if (ToolUtils.isDebugOn())
      monitor.println(bytesToHexString(buffer)); 
    byte[] readBuffer = new byte[1];
    I2cDllByJNA.instance.I2C_DeviceStream(0, deviceAddress, 0, null, 1, readBuffer);
    if (ToolUtils.isDebugOn())
      monitor.println(bytesToHexString(readBuffer)); 
    return readBuffer[0];
  }
  
  private static int checksum(byte[] i2cWriteCmd) {
    return i2cWriteCmd[1] + i2cWriteCmd[2] + i2cWriteCmd[3] + i2cWriteCmd[4] + i2cWriteCmd[5] + i2cWriteCmd[6] & 0xF;
  }
  
  private static int checksumForRun(byte[] i2cWriteCmd) {
    int total = 0;
    for (int i = 0; i < i2cWriteCmd.length; i++) {
      if (i != 0)
        total += i2cWriteCmd[i]; 
    } 
    return total & 0xF;
  }
  
  public static int booleanToInt(boolean bool) {
    return bool ? 1 : 0;
  }
  
  public static int getBaudRate() {
    return baudRate;
  }
  
  public static int getDeviceAddress() {
    return deviceAddress;
  }
}
